devicesinlan_gui - Mariano Muñoz

# NAME

devicesinlan_gui: Scans all devices in your LAN. Then you can set an alias to your known devices in order to detect future strange devices in your net.

# SYNOPSIS

devicesinlan_gui [--help] [--version] [--debug DEBUG]

# DESCRIPCIÓN

En el menú de la aplicación tienes las siguientes funcionalidades:

Dispositivo > Nuevo escaneado

Searches all devices in tha LAN and show them in a new tab. If some device is not in the known devices list it will be shown with a red background. Devices with a green background are trusted devices

Dispositivos > Muestra la base de datos de dispositivos

Muestra todo los dispositivos conocidos en una nueva pestaña.

Hacer click derecho te permite editar la base de datos de dispositivos conocidos.

Dispositivos > Carga una lista de dispositivos

Carga una lista de dispositivos conocidos en formato xml.

Devices > Save devices list

Saves the known devices list to a xml file.

Devices > Reset database

Removes all known devices.

This option erases all known devices in database.

Configuration > Settings

In this dialog you can select your prefered language and you can configure the number of concurrence request.

Ayuda > Ayuda

Muestra esta información de ayuda.

Help > About

Shows information about DevicesInLAN license and authors.

Help > Check for updates

Checks for updates in DevicesInLan repository.

Ayuda > Salir

Exits from program.

Created with libmangenerator at 2018-11-19